Module: RakeCommander::Patcher::Application::TopLevelResume::Patch

Defined in:
lib/rake-commander/patcher/application/top_level_resume.rb

Instance Method Summary collapse

Instance Method Details

#top_levelObject

To preserve rake as main executable, as the RunMethod::Patch is applied only when Rake::Application requires the Rakefile that loads rake-commander, we technically only need to fix the top_level_tasks that have been detected.



30
31
32
33
# File 'lib/rake-commander/patcher/application/top_level_resume.rb', line 30

def top_level
  RakeCommander.rectify_rake_application
  super
end